pub enum CoroutineFrameStep<T = Ref> {
Produced(T),
Consumed(T),
Complete,
}Expand description
The next observable transition from a resumable coroutine frame.
Variants
Produced(T)
The frame produced a value from its producer side.
Consumed(T)
The frame consumed a value on its consumer side.
Complete
Both sides are exhausted.