ResumableFrame

Struct ResumableFrame 

pub struct ResumableFrame<D> { /* private fields */ }
A surface-neutral, one-shot-completion resumable frame.

Implementations

Source

impl<D> ResumableFrame<D>

pub fn new(limits: FrameLimits, driver: D) -> Self

Creates a frame driven by driver under explicit limits.

pub fn is_complete(&self) -> bool

Returns whether the frame has returned or failed.

pub fn resume<T, R, E>( &mut self, packet: ResumePacket<T, E>, ) -> Result<ResumeResult<T, R, E>, FrameError>
where D: FnMut(ResumePacket<T, E>, &mut StepBudget) -> Result<ResumeResult<T, R, E>, FrameError>,

Delivers one packet and returns the next observable transition.