RaisedResumePacket

Type Alias RaisedResumePacket 

pub type RaisedResumePacket<T> = ResumePacket<T, Raised>;
Resume input specialized to throwing the shared raised envelope.

Aliased Type

pub enum RaisedResumePacket<T> {
    Start,
    Send(T),
    Throw(Raised),
    Close,
}

Variants



Start

Start a frame that has not run before.



Send(T)

Send a value into a suspended frame.



Throw(Raised)

Throw an error into a suspended frame.



Close

Ask a suspended frame to close and run its cleanup.