pub struct OneShotControlPolicy { /* private fields */ }Expand description
A control policy that allows each captured continuation to resume once.
Implements the kernel ControlPolicy contract: prompt entry and abort are
unrestricted, but a continuation that has already been resumed cannot be
resumed again. This is the default policy installed by the control lib.
Implementations