pub struct ResumableFrame<D> { /* private fields */ }Expand description
A surface-neutral, one-shot-completion resumable frame.
Implementations
Sourceimpl<D> ResumableFrame<D>
impl<D> ResumableFrame<D>
Sourcepub fn new(limits: FrameLimits, driver: D) -> Self
pub fn new(limits: FrameLimits, driver: D) -> Self
Creates a frame driven by driver under explicit limits.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Returns whether the frame has returned or failed.
Sourcepub fn resume<T, R, E>(
&mut self,
packet: ResumePacket<T, E>,
) -> Result<ResumeResult<T, R, E>, FrameError>
pub fn resume<T, R, E>( &mut self, packet: ResumePacket<T, E>, ) -> Result<ResumeResult<T, R, E>, FrameError>
Delivers one packet and returns the next observable transition.