pub type RaisedResumePacket<T> = ResumePacket<T, Raised>;Expand description
Resume input specialized to throwing the shared raised envelope.
Aliased Type
pub enum RaisedResumePacket<T> {
Start,
Send(T),
Throw(Raised),
Close,
}pub type RaisedResumePacket<T> = ResumePacket<T, Raised>;Resume input specialized to throwing the shared raised envelope.
pub enum RaisedResumePacket<T> {
Start,
Send(T),
Throw(Raised),
Close,
}